@@ -34,9 +34,19 @@
 #pod
 #pod =head1 DESCRIPTION
 #pod
-#pod C<Dist::Zilla> and CPAN do not handle well distributions with no main module. This is a stub "main"
-#pod module of C<Dist-Zilla-Plugin-Hook> distribution, its purpose is making C<Dist::Zilla> and C<CPAN> indexer
-#pod happy. You should not use it.
+#pod This plugin consumes C<Hooker> role like all other C<Hook> plugins. However, this plugin I<never>
+#pod executes its Perl code. Instead, it just stores it for later use by other plugins.
+#pod
+#pod For example, F<dist.ini> section
+#pod
+#pod     [Hook/prologue]
+#pod         . = use autodiue ':all';
+#pod
+#pod specifies code, which will be executed as initial part of all other hooks. Again: C<Hook> itself
+#pod does not execute its code, if there is no other hooks in F<dist.ini>, this code will never execute.
+#pod
+#pod BTW, C<Dist::Zilla> and CPAN do not handle well distributions with no main module. This is also a
+#pod "main" module of C<Dist-Zilla-Plugin-Hook> distribution, to make C<Dist::Zilla> and C<CPAN> indexer happy.
 #pod
 #pod =head1 SEE ALSO
 #pod
@@ -53,24 +63,11 @@ use Moose;
 use namespace::autoclean;
 
 # ABSTRACT: Write C<Dist::Zilla> plugin directly in F<dist.ini>
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 with 'Dist::Zilla::Role::Plugin';
 with 'Dist::Zilla::Role::ErrorLogger' => { -version => 0.005 };
-
-#pod =for Pod::Coverage BUILD
-#pod
-#pod =cut
-
-sub BUILD {
-    my ( $self ) = @_;
-    $self->log_error( join( "\n",
-        "This is a stub and should not be used.",
-        "Use Hook subclasses, like Hook::Config or Hook::BeforeBuild.",
-    ) );
-    $self->abort();
-    return;
-};
+with 'Dist::Zilla::Role::Hooker';
 
 __PACKAGE__->meta->make_immutable();
 
@@ -104,7 +101,7 @@ Dist::Zilla::Plugin::Hook - Write C<Dist::Zilla> plugin directly in F<dist.ini>
 
 =head1 VERSION
 
-Version 0.001, released on 2015-07-22 08:39 UTC.
+Version 0.002, released on 2015-07-23 22:08 UTC.
 
 =head1 WHAT?
 
@@ -120,11 +117,19 @@ in the L<readme|Dist::Zilla::Plugin::Hook::ReadMe>.
 
 =head1 DESCRIPTION
 
-C<Dist::Zilla> and CPAN do not handle well distributions with no main module. This is a stub "main"
-module of C<Dist-Zilla-Plugin-Hook> distribution, its purpose is making C<Dist::Zilla> and C<CPAN> indexer
-happy. You should not use it.
+This plugin consumes C<Hooker> role like all other C<Hook> plugins. However, this plugin I<never>
+executes its Perl code. Instead, it just stores it for later use by other plugins.
 
-=for Pod::Coverage BUILD
+For example, F<dist.ini> section
+
+    [Hook/prologue]
+        . = use autodiue ':all';
+
+specifies code, which will be executed as initial part of all other hooks. Again: C<Hook> itself
+does not execute its code, if there is no other hooks in F<dist.ini>, this code will never execute.
+
+BTW, C<Dist::Zilla> and CPAN do not handle well distributions with no main module. This is also a
+"main" module of C<Dist-Zilla-Plugin-Hook> distribution, to make C<Dist::Zilla> and C<CPAN> indexer happy.
 
 =head1 SEE ALSO
 
