@@ -57,7 +57,7 @@ use Moose::Role;
 use namespace::autoclean;
 
 # ABSTRACT: Run Perl code written in your plugin's F<dist.ini> section
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 with 'Dist::Zilla::Role::Plugin';
 with 'Dist::Zilla::Role::ErrorLogger' => { -version => 0.005 };
@@ -90,6 +90,10 @@ has code => (
 
 #pod =method hook
 #pod
+#pod     $ret = $self->hook( @args );
+#pod     @ret = $self->hook( @args );
+#pod     $self->hook( @args );
+#pod
 #pod This is the primary method of the role. The method executes Perl code specified in C<code>
 #pod attribute with string C<eval>. The method passes arguments specified by the caller to the code, and
 #pod passes the code return value back to the caller. Calling context (list, scalar, or void) is
@@ -100,9 +104,10 @@ has code => (
 #pod Following lexical variables are exposed to the code intentionally:
 #pod
 #pod =for :list
-#pod = C<$plugin>
 #pod = C<$self>
+#pod = C<$plugin>
 #pod Reference to the plugin object executing the code (such as C<Hook::Init> or C<Hook::BeforeBuild>).
+#pod = C<$zilla>
 #pod = C<$dist>
 #pod Reference to C<Dist::Zilla> object, the same as C<< $self->zilla >>.
 #pod = C<$arg>
@@ -119,9 +124,10 @@ sub hook {                  ## no critic ( RequireArgUnpacking )
     if ( not $self->code ) {
         return;
     };
-    my $plugin = $self;             # `eval` sees this variable.
-    my $dist   = $self->zilla;      # And this variable too.
-    my $arg    = $_[ 0 ];           # The first argument.
+    my $zilla  = $self->zilla;      # `eval` sees these variables.
+    my $plugin = $self;
+    my $dist   = $zilla;
+    my $arg    = $_[ 0 ];
     my $code   =                    # Declaration is not yet completed, `eval` will not see it.
         sub {
             #~ local $SIG{ __DIE__ };   # TODO: Should I cancel die handler, if any is set?
@@ -133,6 +139,8 @@ sub hook {                  ## no critic ( RequireArgUnpacking )
             eval(           ## no critic ( ProhibitStringyEval, RequireCheckingReturnValueOfEval )
                 join(
                     "\n",
+                    '#line 1 prologue',
+                    $self->prologue,
                     '#line 1 ' . $self->plugin_name,        # It makes error repoting nicier.
                     $self->code
                 )
@@ -159,6 +167,28 @@ sub hook {                  ## no critic ( RequireArgUnpacking )
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =method prologue
+#pod
+#pod     my @code = $self->prologue;
+#pod
+#pod The methods returns prologue code.
+#pod
+#pod Prologue code is extracted from C<Dist::Zilla> plugin named C<prologue>.
+#pod
+#pod =cut
+
+sub prologue {
+    my ( $self ) = @_;
+    my $zilla = $self->zilla;
+    my $prologue = $zilla->plugin_named( 'prologue' );
+    if ( $prologue and $prologue->meta->does_role( 'Dist::Zilla::Role::Hooker' ) ) {
+        return $prologue->code;
+    };
+    return ();
+};
+
+# --------------------------------------------------------------------------------------------------
+
 #pod =method mvp_multivalue_args
 #pod
 #pod The method tells C<Dist::Zilla> that dot (C<.>) is a multi-value option.
@@ -211,7 +241,7 @@ Dist::Zilla::Role::Hooker - Run Perl code written in your plugin's F<dist.ini> s
 
 =head1 VERSION
 
-Version 0.001, released on 2015-07-22 08:39 UTC.
+Version 0.002, released on 2015-07-23 22:08 UTC.
 
 =head1 WHAT?
 
@@ -249,6 +279,10 @@ specified using this notation:
 
 =head2 hook
 
+    $ret = $self->hook( @args );
+    @ret = $self->hook( @args );
+    $self->hook( @args );
+
 This is the primary method of the role. The method executes Perl code specified in C<code>
 attribute with string C<eval>. The method passes arguments specified by the caller to the code, and
 passes the code return value back to the caller. Calling context (list, scalar, or void) is
@@ -260,12 +294,14 @@ Following lexical variables are exposed to the code intentionally:
 
 =over 4
 
-=item C<$plugin>
-
 =item C<$self>
 
+=item C<$plugin>
+
 Reference to the plugin object executing the code (such as C<Hook::Init> or C<Hook::BeforeBuild>).
 
+=item C<$zilla>
+
 =item C<$dist>
 
 Reference to C<Dist::Zilla> object, the same as C<< $self->zilla >>.
@@ -282,6 +318,14 @@ C<hook> arguments, self-reference is already shifted!
 
 If code dies, the method logs error message and aborts C<Dist::Zilla>.
 
+=head2 prologue
+
+    my @code = $self->prologue;
+
+The methods returns prologue code.
+
+Prologue code is extracted from C<Dist::Zilla> plugin named C<prologue>.
+
 =head2 mvp_multivalue_args
 
 The method tells C<Dist::Zilla> that dot (C<.>) is a multi-value option.
